Structs
- Order
- An order is a public, timebound offer to buy a given token at a fixed price.
- Receipt
- A receipt tracks a deposit to fill an order.
Enums
Functions
- order_
pda - Fetch PDA of the order account.
- receipt_
pda - Fetch PDA of the receipt account.