#[repr(C)]pub struct Order {}Expand description
An order is a public, timebound offer to buy a given token at a fixed price.
Fields
The maker of the order.
amount_a: u64The amount of token A offered by the authority and locked in escrow.
amount_b: u64The amount of token B requested by the authority.
expires_at: i64The time at which the order expires.
fee: u64👎Deprecated since 0.1.4: Fee no longer supported
An optional fee to be paid by the authority if the order is filled.
fee_collector: Pubkey👎Deprecated since 0.1.4: Fee no longer supported
The collector of the fee.
id: u64A unique identifier for the order, namespaced by the authority.
mint_a: PubkeyThe mint of token A.
mint_b: PubkeyThe mint of token B.
total_deposits: u64The total amount of token B deposited by takers.
total_receipts: u64The total number receipts issued for this order.
total_redeemed: u64The total amount of receipts redeemed by takers.
is_collected: u64Is collected.
Implementations