Module state

Module state 

Structs

Order
An order is a public, timebound offer to buy a given token at a fixed price.
Receipt
A receipt tracks a deposit to fill an order.

Enums

ProtobookAccount

Functions

order_pda
Fetch PDA of the order account.
receipt_pda
Fetch PDA of the receipt account.